LiveTextField class

A text field widget, similar to TextField, with content controlled by a MutableCell.

The content of the text field is controlled by a MutableCell which is passed on construction. Whenever the value of the cell changes, the content of the text field is updated to reflect the value of the cell. Similarly, whenever the content of the text field changes, the value of the cell is updated to reflect the field content.

Similar to the content cell, the cell provided for selection is synchronized with the text selection of the field.

Inheritance

Constructors

LiveTextField({Key? key, required MutableCell<String> content, MutableCell<TextSelection>? selection, Object groupId = EditableText, FocusNode? focusNode, UndoHistoryController? undoController, InputDecoration? decoration = const InputDecoration(), TextInputType? keyboardType, TextInputAction? textInputAction, TextCapitalization textCapitalization = TextCapitalization.none, TextStyle? style, StrutStyle? strutStyle, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, TextDirection? textDirection, bool readOnly = false, ToolbarOptions? toolbarOptions, bool? showCursor, bool autofocus = false, WidgetStatesController? statesController, String obscuringCharacter = '•', bool obscureText = false, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = true, int? maxLines = 1, int? minLines, bool expands = false, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, void onChanged(String)?, void onEditingComplete()?, void onSubmitted(String)?, void onAppPrivateCommand(String, Map<String, dynamic>)?, List<TextInputFormatter>? inputFormatters, ValueCell<bool?>? enabled, bool? ignorePointers, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, bool? cursorOpacityAnimates, Color? cursorColor, Color? cursorErrorColor, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, Brightness? keyboardAppearance, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool? enableInteractiveSelection, bool? selectAllOnFocus, TextSelectionControls? selectionControls, void onTap()?, bool onTapAlwaysCalled = false, void onTapOutside(PointerDownEvent)?, void onTapUpOutside(PointerUpEvent)?, MouseCursor? mouseCursor, Widget? buildCounter(BuildContext, {required int currentLength, required bool isFocused, required int? maxLength})?, ScrollController? scrollController, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints = const <String>[], ContentInsertionConfiguration? contentInsertionConfiguration, Clip clipBehavior = Clip.hardEdge, String? restorationId, bool scribbleEnabled = true, bool stylusHandwritingEnabled = EditableText.defaultStylusHandwritingEnabled, bool enableIMEPersonalizedLearning = true, bool canRequestFocus = true, SpellCheckConfiguration? spellCheckConfiguration, TextMagnifierConfiguration? magnifierConfiguration, List<Locale>? hintLocales})
const

Properties

autocorrect → bool?
final
autofillHints → Iterable<String>?
final
autofocus → bool
final
buildCounter → Widget? Function(BuildContext, {required int currentLength, required bool isFocused, required int? maxLength})?
final
canRequestFocus → bool
final
clipBehavior → Clip
final
content → MutableCell<String>
Cell holding the content of the field
final
contentInsertionConfiguration → ContentInsertionConfiguration?
final
cursorColor → Color?
final
cursorErrorColor → Color?
final
cursorHeight → double?
final
cursorOpacityAnimates → bool?
final
cursorRadius → Radius?
final
cursorWidth → double
final
decoration → InputDecoration?
final
dragStartBehavior → DragStartBehavior
final
enabled → ValueCell<bool?>?
final
enableIMEPersonalizedLearning → bool
final
enableInteractiveSelection → bool?
final
enableSuggestions → bool
final
expands → bool
final
focusNode → FocusNode?
final
groupId → Object
final
hashCode → int
The hash code for this object.
no setterinherited
hintLocales → List<Locale>?
final
ignorePointers → bool?
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness?
final
keyboardType → TextInputType?
final
magnifierConfiguration → TextMagnifierConfiguration?
final
maxLength → int?
final
maxLengthEnforcement → MaxLengthEnforcement?
final
maxLines → int?
final
minLines → int?
final
mouseCursor → MouseCursor?
final
obscureText → bool
final
obscuringCharacter → String
final
onAppPrivateCommand → void Function(String, Map<String, dynamic>)?
final
onChanged → void Function(String)?
final
onEditingComplete → void Function()?
final
onSubmitted → void Function(String)?
final
onTap → void Function()?
final
onTapAlwaysCalled → bool
final
onTapOutside → void Function(PointerDownEvent)?
final
onTapUpOutside → void Function(PointerUpEvent)?
final
readOnly → bool
final
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled → bool
final
scrollController → ScrollController?
final
scrollPadding → EdgeInsets
final
scrollPhysics → ScrollPhysics?
final
selectAllOnFocus → bool?
final
selection → MutableCell<TextSelection>?
Cell holding the text selection
final
selectionControls → TextSelectionControls?
final
selectionHeightStyle → BoxHeightStyle?
final
selectionWidthStyle → BoxWidthStyle?
final
showCursor → bool?
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
spellCheckConfiguration → SpellCheckConfiguration?
final
statesController → WidgetStatesController?
final
strutStyle → StrutStyle?
final
style → TextStyle?
final
stylusHandwritingEnabled → bool
final
textAlign → TextAlign
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization
final
textDirection → TextDirection?
final
textInputAction → TextInputAction?
final
toolbarOptions → ToolbarOptions?
final
undoController → UndoHistoryController?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<LiveTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited