LiveTextFormField class

A TextFormField widget with Live Cells integration.

The content cell controls the text content of the field. The selection cell controls the text selection in the field.

All standard TextFormField callbacks are supported and will be called in addition to updating the corresponding cells.

Inheritance

Constructors

LiveTextFormField({Key? key, required MutableCell<String> content, MutableCell<TextSelection>? selection, Object groupId = EditableText, String? initialValue, FocusNode? focusNode, String? forceErrorText, InputDecoration? decoration = const InputDecoration(), TextInputType? keyboardType, TextCapitalization textCapitalization = TextCapitalization.none, TextInputAction? textInputAction, TextStyle? style, StrutStyle? strutStyle, TextDirection? textDirection, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, bool autofocus = false, bool readOnly = false, bool? showCursor, String obscuringCharacter = '•', bool obscureText = false, bool autocorrect = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = true, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines = 1, int? minLines, bool expands = false, int? maxLength, void onChanged(String)?, void onTap()?, bool onTapAlwaysCalled = false, void onTapOutside(PointerDownEvent)?, void onTapUpOutside(PointerUpEvent)?, void onEditingComplete()?, void onFieldSubmitted(String)?, void onSaved(String?)?, String? validator(String?)?, Widget errorBuilder(BuildContext, String)?, List<TextInputFormatter>? inputFormatters, ValueCell<bool?>? enabled, bool? ignorePointers, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Color? cursorErrorColor, Brightness? keyboardAppearance, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), bool? enableInteractiveSelection, bool? selectAllOnFocus, TextSelectionControls? selectionControls, Widget? buildCounter(BuildContext, {required int currentLength, required bool isFocused, required int? maxLength})?, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, ScrollController? scrollController, String? restorationId, bool enableIMEPersonalizedLearning = true, MouseCursor? mouseCursor, SpellCheckConfiguration? spellCheckConfiguration, TextMagnifierConfiguration? magnifierConfiguration, UndoHistoryController? undoController, void onAppPrivateCommand(String, Map<String, dynamic>)?, bool? cursorOpacityAnimates, BoxHeightStyle? selectionHeightStyle, BoxWidthStyle? selectionWidthStyle, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ContentInsertionConfiguration? contentInsertionConfiguration, WidgetStatesController? statesController, Clip clipBehavior = Clip.hardEdge, bool scribbleEnabled = true, bool stylusHandwritingEnabled = EditableText.defaultStylusHandwritingEnabled, bool canRequestFocus = true, List<Locale>? hintLocales})
const

Properties

autocorrect → bool
final
autofillHints → Iterable<String>?
final
autofocus → bool
final
autovalidateMode → AutovalidateMode?
final
buildCounter → Widget? Function(BuildContext, {required int currentLength, required bool isFocused, required int? maxLength})?
final
canRequestFocus → bool
final
clipBehavior → Clip
final
content → MutableCell<String>
Cell holding the content of the field
final
contentInsertionConfiguration → ContentInsertionConfiguration?
final
cursorColor → Color?
final
cursorErrorColor → Color?
final
cursorHeight → double?
final
cursorOpacityAnimates → bool?
final
cursorRadius → Radius?
final
cursorWidth → double
final
decoration → InputDecoration?
final
dragStartBehavior → DragStartBehavior
final
enabled → ValueCell<bool?>?
final
enableIMEPersonalizedLearning → bool
final
enableInteractiveSelection → bool?
final
enableSuggestions → bool
final
errorBuilder → Widget Function(BuildContext, String)?
final
expands → bool
final
focusNode → FocusNode?
final
forceErrorText → String?
final
groupId → Object
final
hashCode → int
The hash code for this object.
no setterinherited
hintLocales → List<Locale>?
final
ignorePointers → bool?
final
initialValue → String?
final
inputFormatters → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness?
final
keyboardType → TextInputType?
final
magnifierConfiguration → TextMagnifierConfiguration?
final
maxLength → int?
final
maxLengthEnforcement → MaxLengthEnforcement?
final
maxLines → int?
final
minLines → int?
final
mouseCursor → MouseCursor?
final
obscureText → bool
final
obscuringCharacter → String
final
onAppPrivateCommand → void Function(String, Map<String, dynamic>)?
final
onChanged → void Function(String)?
final
onEditingComplete → void Function()?
final
onFieldSubmitted → void Function(String)?
final
onSaved → void Function(String?)?
final
onTap → void Function()?
final
onTapAlwaysCalled → bool
final
onTapOutside → void Function(PointerDownEvent)?
final
onTapUpOutside → void Function(PointerUpEvent)?
final
readOnly → bool
final
restorationId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled → bool
final
scrollController → ScrollController?
final
scrollPadding → EdgeInsets
final
scrollPhysics → ScrollPhysics?
final
selectAllOnFocus → bool?
final
selection → MutableCell<TextSelection>?
Cell holding the text selection in the field
final
selectionControls → TextSelectionControls?
final
selectionHeightStyle → BoxHeightStyle?
final
selectionWidthStyle → BoxWidthStyle?
final
showCursor → bool?
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
spellCheckConfiguration → SpellCheckConfiguration?
final
statesController → WidgetStatesController?
final
strutStyle → StrutStyle?
final
style → TextStyle?
final
stylusHandwritingEnabled → bool
final
textAlign → TextAlign
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization
final
textDirection → TextDirection?
final
textInputAction → TextInputAction?
final
undoController → UndoHistoryController?
final
validator → String? Function(String?)?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<LiveTextFormField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited